@@ -42,7 +42,8 @@ def _progress(data):
 
 class Savify:
     def __init__(self, api_credentials=None, quality=Quality.BEST, download_format=Format.MP3,
-                 group=None, quiet: bool = False, path_holder: PathHolder = None, retry: int = 3):
+                 group=None, quiet: bool = False, path_holder: PathHolder = None, retry: int = 3,
+                 ydl_options: dict = {}, skip_cover_art: bool = False):
 
         self.downloaded_cover_art = {}
         self.download_format = download_format
@@ -52,6 +53,8 @@ class Savify:
         self.group = group
         self.quiet = quiet
         self.retry = retry
+        self.ydl_options = ydl_options
+        self.skip_cover_art = skip_cover_art
 
         if api_credentials is None:
             if not (check_env()):
@@ -160,8 +163,11 @@ class Savify:
                 '-metadata', f'disc={track.disc_number}',
                 '-metadata', f'track={track.track_number}/{track.album_track_count}',
             ],
+            **self.ydl_options,
         }
 
+        output_temp = output_temp.replace('%(ext)s', self.download_format)
+
         if self.download_format == Format.MP3:
             options['postprocessor_args'].append('-codec:a')
             options['postprocessor_args'].append('libmp3lame')
@@ -184,15 +190,23 @@ class Savify:
                     print(logger.log)
                     return status
 
-        attempt = 0
-        added_artwork = False
+        if self.download_format != Format.MP3 or self.skip_cover_art:
+            try:
+                import shutil
+                shutil.move(output_temp, output)
+            except RuntimeError:
+                status['returncode'] = 1
+                status['error'] = "Unknown."
+                return status
 
-        if not self.download_format == Format.MP3:
             status['returncode'] = 0
             return status
 
         from ffmpy import FFRuntimeError
 
+        attempt = 0
+        added_artwork = False
+
         while not added_artwork:
             attempt += 1
 
@@ -205,8 +219,6 @@ class Savify:
                     cover_art = self.path_holder.download_file(track.cover_art_url, extension='jpg')
                     self.downloaded_cover_art[cover_art_name] = cover_art
 
-                output_temp = output_temp.replace('%(ext)s', self.download_format)
-
                 ffmpeg = FFmpeg(
                     inputs={output_temp: None, str(cover_art): None, },
                     outputs={output: '-loglevel quiet -hide_banner -y -map 0:0 -map 1:0 -c copy -id3v2_version 3 '
@@ -225,11 +237,12 @@ class Savify:
             except FFRuntimeError:
                 if attempt > self.retry:
                     try:
-                        os.rename(output_temp, output)
+                        import shutil
+                        shutil.move(output_temp, output)
                         added_artwork = True
                     except RuntimeError:
                         status['returncode'] = 1
-                        status['error'] = "Failed to add cover art."
+                        status['error'] = "Unknown."
                         return status
 
         status['returncode'] = 0
